ccai

package
v0.0.0-...-1993c60 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 1, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package ccai provides the main export for the CCAI Go module

Index

Constants

const Version = "1.0.0"

Version is the current version of the CCAI Go client

Variables

var NewClient = ccai.NewClient

NewClient creates a new CCAI client instance

Functions

This section is empty.

Types

type Account

type Account = ccai.Account

Account represents a recipient account

type Client

type Client = ccai.Client

Client is the main client for interacting with the CloudContactAI API

type Config

type Config = ccai.Config

Config represents the configuration for the CCAI client

type EmailAccount

type EmailAccount = email.EmailAccount

Email types

type EmailCampaign

type EmailCampaign = email.EmailCampaign

Main CCAI types

type EmailOptions

type EmailOptions = email.EmailOptions

Main CCAI types

type EmailResponse

type EmailResponse = email.EmailResponse

Main CCAI types

type Options

type Options = sms.Options

Main CCAI types

type Response

type Response = sms.Response

SMS types

type SignedURLResponse

type SignedURLResponse = sms.SignedURLResponse

Main CCAI types

Directories

Path Synopsis
examples
basic command
Package main provides a basic example of using the CCAI Go client.
Package main provides a basic example of using the CCAI Go client.
email command
Example demonstrating email sending functionality
Example demonstrating email sending functionality
mms command
Package main provides an example of using the MMS functionality of the CCAI Go client.
Package main provides an example of using the MMS functionality of the CCAI Go client.
progress_tracking command
Package main provides an example of using progress tracking with the CCAI Go client.
Package main provides an example of using progress tracking with the CCAI Go client.
sms command
webhook command
Package main provides an example of using the CCAI Go webhook functionality.
Package main provides an example of using the CCAI Go webhook functionality.
pkg
ccai
Package ccai provides a client for interacting with the Cloud Contact AI API.
Package ccai provides a client for interacting with the Cloud Contact AI API.
contact
Package contact provides functionality for managing contact preferences (opt-out).
Package contact provides functionality for managing contact preferences (opt-out).
email
Package email provides email campaign functionality for the CCAI API.
Package email provides email campaign functionality for the CCAI API.
sms
Package sms provides functionality for sending SMS messages through the CCAI API.
Package sms provides functionality for sending SMS messages through the CCAI API.
testutil
Package testutil provides shared test utilities for the CCAI Go SDK.
Package testutil provides shared test utilities for the CCAI Go SDK.
webhook
Package webhook provides HTTP handler utilities for CloudContactAI webhooks.
Package webhook provides HTTP handler utilities for CloudContactAI webhooks.

Jump to